<template>
	<div class='widget-wrapper' :style='{...widgetWrapperStyle, ...transitionStyle}'>
		<a :href='link' class='widget' v-if='video_src' target="_blank" rel="noopener noreferrer" :class='{hovered}'>
			<div class='video' :class='{mounted}'>
				<video :src='video_src' muted loop autoplay ref='video' />
			</div>

			<a class='link-button' :href='link' target="_blank" rel="noopener noreferrer">
				<span class='category'>{{category}}</span>
				<span class='caption' v-html='title'>{{title}}</span>
			</a>
		</a>
	</div>
</template>

<script>

import {widgetMixin, transitionMixin, positionMixin} from '../helpers/widgets.mjs'

export default {
	data() {
		return {
			video_src: null,
			category: null,
			title: null,
			link: null,
			mounted: false,
			hovered: false,
			animationStarted: false,
		}
	},

	mixins: [widgetMixin, positionMixin, transitionMixin],

	created() {
		this.getData().then(() => {
			this.$nextTick(() => this.startAnimation())
		})
	},

	mounted() {
		this.startAnimation()
	},

	beforeUnmount() {
		this.mounted = false
	},

	computed: {
	},

	methods: {
		startAnimation() {
			const video = this.$refs.video
			if (!video || this.animationStarted) return

			this.animationStarted = true

			const load = () => {
				video.play()

				setTimeout(() => {
					this.mounted = true
					this.hovered = true

					setTimeout(() => (this.hovered = false), 5000)
				}, 1000)
			}

			if (video.readyState >= 4) load()
			else video.addEventListener('canplay', load, {once: true})
		},
	},
}

</script>

<style scoped>
a {
	text-decoration: none;
}

.widget-wrapper {
	z-index: 2;

	--video-width: 6em;
	--video-scale: 1.6;
}

.widget {
	position: absolute;
	left: -1%;
	top: -1%;
	pointer-events: all;

	display: flex;
	align-items: center;
}

.video {
	width: calc(var(--video-width) * var(--video-scale));
	aspect-ratio: 1;
	clip-path: circle(0% at 35% 35%);

	transition: clip-path .5s ease-out, transform .5s ease-out;

	margin-right: -2em;

	transform: translate(-15%, -15%)
}

.video.mounted {
	clip-path: circle(35% at center center);
}

.widget:hover .video, .widget.hovered .video {
	clip-path: circle(49% at center center) !important;
	transform: none
}

.widget:hover video, .widget.hovered video {
	transform: scale(1.05);
}


video {
	width: 100%;
	aspect-ratio: 1;

	object-fit: cover;
	transition: transform .5s ease-out;
}

.link-button {
	background: rgba(0, 0, 0, 0.15);
	backdrop-filter: blur(20px);

	border-radius: .7em;

	display: flex;
	flex-direction: column;

	color: white;
	font-family: var(--primary-font);
	padding: .8em .9em;

	width: 15em;

	font-size: .8em;
	font-weight: 400;
	font-variation-settings: 'wght' 300;

	gap: .3em;

	transition: opacity .5s ease-out, background .2s ease;
	opacity: 0;

	z-index: 1;
}

.link-button:hover {
	background: rgba(0, 0, 0, 0.05);
	color: white;
}

.widget:hover .link-button, .widget.hovered .link-button {
	opacity: 1;
}

.category {
	letter-spacing: .15em;
	text-transform: uppercase;
	font-variation-settings: 'wght' 600;
	font-size: .7em;
	color: #FFAF65;
}


</style>
